/* Correlation test */

pwcorr rule gov corr

pwcorr rule gov corr democracy



/* Correlation between the two DVs */

drop if flex_score1==0

corr flex_score1 flex_score2



/* Descriptive statistics - Table 1 */

sum pta flex_score1 flex_score2 corr rule trade_ln gov gdp_growth gdp gdppc democracy alliance wto french_colony otherthan_french_colony distance us_pta spatial trade_dispute eu_potential landlocked island trade_opennes



/* Heckman model - Table 2 */

heckman flex_score1 corr gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = corr french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score1 rule gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = rule french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score1 gov gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = gov french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon



/* Heckman model - Table 3 */

heckman flex_score2 corr gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = corr french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score2 rule gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = rule french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score2 gov gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = gov french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon



/* Prediction - Selection Model - Table 4 */

heckman flex_score1 corr gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = corr french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

mfx, predict(psel) varlist(corr) at(corr=.37)

mfx, predict(psel) varlist(corr) at(corr=4.01)


heckman flex_score1 rule gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = rule french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

mfx, predict(psel) varlist(rule) at(rule=.13)

mfx, predict(psel) varlist(rule) at(rule=3.84)


heckman flex_score1 gov gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = gov french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

mfx, predict(psel) varlist(gov) at(gov=.16)

mfx, predict(psel) varlist(gov) at(gov=3.81)



/* Good of Fit - Selection Model - Table 5 */

heckman flex_score1 corr gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = corr french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

predict psel, psel

list country_a if psel>0.5


heckman flex_score1 rule gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = rule french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

predict psel, psel

list country_a if psel>0.5


heckman flex_score1 gov gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = gov french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

predict psel, psel

list country_a if psel>0.5



/* Robustness check */


/* Probit model - cross-section - Table 6 */

use "dataset_cross-section_083009.dta"

probit pta transp gdp_ln gdppc alliance democracy trade_ln distance, robust

probit pta corr gdp_ln gdppc alliance democracy trade_ln distance, robust



/* Tobit model - cross-section - Table 7 and Table 8 */

tobit flex_score1 trans colony gdp gdp_growth trade_ln us_pta democracy, robust ll(0)

tobit flex_score2 trans colony gdp gdp_growth trade_ln us_pta democracy, robust ll(0)

tobit flex_score1 corr colony gdp gdp_growth trade_ln us_pta democracy, robust ll(0)

tobit flex_score2 corr colony gdp gdp_growth trade_ln us_pta democracy, robust ll(0)



/* Including year-dummy */

gen year_1990=0

replace year_1990=1 if year==1990

gen year_1991=0

replace year_1991=1 if year==1991

gen year_1992=0

replace year_1992=1 if year==1992

gen year_1993=0

replace year_1993=1 if year==1993

gen year_1994=0

replace year_1994=1 if year==1994

gen year_1995=0

replace year_1995=1 if year==1995

gen year_1996=0

replace year_1996=1 if year==1996

gen year_1997=0

replace year_1997=1 if year==1997

gen year_1998=0

replace year_1998=1 if year==1998

gen year_1999=0

replace year_1999=1 if year==1999

gen year_2000=0

replace year_2000=1 if year==2000

gen year_2001=0

replace year_2001=1 if year==2001

gen year_2002=0

replace year_2002=1 if year==2002

gen year_2003=0

replace year_2003=1 if year==2003

gen year_2004=0

replace year_2004=1 if year==2004

gen year_2005=0

replace year_2005=1 if year==2005


heckman flex_score1 corr gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = corr french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4 year_1990 year_1991 year_1992 year_1993 year_1994 year_1995 year_1996 year_1997 year_1998 year_1999 year_2001 year_2002 year_2003 year_2004 year_2005) robust nocon

heckman flex_score1 rule gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = rule french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4 year_1990 year_1991 year_1992 year_1993 year_1994 year_1995 year_1996 year_1997 year_1998 year_1999 year_2001 year_2002 year_2003 year_2004 year_2005) robust nocon

heckman flex_score1 gov gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = gov french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4 year_1990 year_1991 year_1992 year_1993 year_1994 year_1995 year_1996 year_1997 year_1998 year_1999 year_2001 year_2002 year_2003 year_2004 year_2005) robust nocon


heckman flex_score2 corr gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = corr french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4 year_1990 year_1991 year_1992 year_1993 year_1994 year_1995 year_1996 year_1997 year_1998 year_1999 year_2001 year_2002 year_2003 year_2004 year_2005) robust nocon

heckman flex_score2 rule gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = rule french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4 year_1990 year_1991 year_1992 year_1993 year_1994 year_1995 year_1996 year_1997 year_1998 year_1999 year_2001 year_2002 year_2003 year_2004 year_2005) robust nocon

heckman flex_score2 gov gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = gov french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4 year_1990 year_1991 year_1992 year_1993 year_1994 year_1995 year_1996 year_1997 year_1998 year_1999 year_2001 year_2002 year_2003 year_2004 year_2005) robust nocon



/* Including More Variables */

heckman flex_score1 corr gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = corr french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial gdp_g landlocked island wto potential_eu_candidates trade_dispute _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score1 rule gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = rule french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial gdp_g landlocked island wto potential_eu_candidates trade_dispute _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score1 gov gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = gov french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial gdp_g landlocked island wto potential_eu_candidates trade_dispute _sduration1 _sduration2 _sduration3 _sduration4) robust nocon


heckman flex_score2 corr gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = corr french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial gdp_g landlocked island wto potential_eu_candidates trade_dispute _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score2 rule gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = rule french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial gdp_g landlocked island wto potential_eu_candidates trade_dispute _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score2 gov gdp_growth french_colony otherthan_french_colony democracy gdppc gdp_ln trade_ln us, select(pta = gov french_colony otherthan_french_colony us gdp_ln democracy alliance distance wto trade_ln spatial gdp_g landlocked island wto potential_eu_candidates trade_dispute _sduration1 _sduration2 _sduration3 _sduration4) robust nocon



/* Excluding variable not statistically significant */

heckman flex_score1 corr gdp_growth democracy gdp_ln trade_ln, select(pta = corr otherthan_french_colony us gdp_ln democracy distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score1 rule gdp_growth democracy gdp_ln trade_ln, select(pta = rule otherthan_french_colony us gdp_ln democracy distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score1 gov gdp_growth democracy gdp_ln trade_ln, select(pta = gov otherthan_french_colony us gdp_ln democracy distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon


heckman flex_score2 corr gdp_growth democracy gdp_ln trade_ln, select(pta = corr otherthan_french_colony us gdp_ln democracy distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score2 rule gdp_growth democracy gdp_ln trade_ln, select(pta = rule otherthan_french_colony us gdp_ln democracy distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon

heckman flex_score2 gov gdp_growth democracy gdp_ln trade_ln, select(pta = gov otherthan_french_colony us gdp_ln democracy distance wto trade_ln spatial _sduration1 _sduration2 _sduration3 _sduration4) robust nocon


